
import msgpackrpc
from types import *


class classifier:
  def __init__ (self, host, port):
    address = msgpackrpc.Address(host, port)
    self.client = msgpackrpc.Client(address)

  def set_config (self, name, c):
    retval = self.client.call('set_config', name, c)
    return retval

  def get_config (self, name):
    retval = self.client.call('get_config', name)
    return config_data.from_msgpack(retval)

  def train (self, name, data):
    retval = self.client.call('train', name, data)
    return retval

  def classify (self, name, data):
    retval = self.client.call('classify', name, data)
    return [[estimate_result.from_msgpack(elem_elem_retval) for elem_elem_retval in elem_retval] for elem_retval in retval]

  def save (self, name, arg1):
    retval = self.client.call('save', name, arg1)
    return retval

  def load (self, name, arg1):
    retval = self.client.call('load', name, arg1)
    return retval

  def get_status (self, name):
    retval = self.client.call('get_status', name)
    return {k_retval : {k_v_retval : v_v_retval for k_v_retval,v_v_retval in v_retval.items()} for k_retval,v_retval in retval.items()}






# This file is auto-generated from src/server/recommender.idl
# *** DO NOT EDIT ***


import sys
import msgpack


class param_t:
  @staticmethod
  def from_msgpack(arg):
    return {k_arg : v_arg for k_arg,v_arg in arg.items()}

class similar_result:
  @staticmethod
  def from_msgpack(arg):
    return [ (elem_arg[0], elem_arg[1], )  for elem_arg in arg]

class string_rule:
  def __init__(self, key, t, sample_weight, global_weight):
    self.key = key
    self.t = t
    self.sample_weight = sample_weight
    self.global_weight = global_weight

  def to_msgpack(self):
    return (
      self.key,
      self.t,
      self.sample_weight,
      self.global_weight,
      )

  @staticmethod
  def from_msgpack(arg):
    return string_rule(
      arg[0],
      arg[1],
      arg[2],
      arg[3])

class filter_rule:
  def __init__(self, key, t, suffix):
    self.key = key
    self.t = t
    self.suffix = suffix

  def to_msgpack(self):
    return (
      self.key,
      self.t,
      self.suffix,
      )

  @staticmethod
  def from_msgpack(arg):
    return filter_rule(
      arg[0],
      arg[1],
      arg[2])

class num_rule:
  def __init__(self, key, t):
    self.key = key
    self.t = t

  def to_msgpack(self):
    return (
      self.key,
      self.t,
      )

  @staticmethod
  def from_msgpack(arg):
    return num_rule(
      arg[0],
      arg[1])

class converter_config:
  def __init__(self, string_filter_types, string_filter_rules, num_filter_types, num_filter_rules, string_types, string_rules, num_types, num_rules):
    self.string_filter_types = string_filter_types
    self.string_filter_rules = string_filter_rules
    self.num_filter_types = num_filter_types
    self.num_filter_rules = num_filter_rules
    self.string_types = string_types
    self.string_rules = string_rules
    self.num_types = num_types
    self.num_rules = num_rules

  def to_msgpack(self):
    return (
      self.string_filter_types,
      self.string_filter_rules,
      self.num_filter_types,
      self.num_filter_rules,
      self.string_types,
      self.string_rules,
      self.num_types,
      self.num_rules,
      )

  @staticmethod
  def from_msgpack(arg):
    return converter_config(
      {k_arg_0_ : param_t.from_msgpack(v_arg_0_) for k_arg_0_,v_arg_0_ in arg[0].items()},
      [filter_rule.from_msgpack(elem_arg_1_) for elem_arg_1_ in arg[1]],
      {k_arg_2_ : param_t.from_msgpack(v_arg_2_) for k_arg_2_,v_arg_2_ in arg[2].items()},
      [filter_rule.from_msgpack(elem_arg_3_) for elem_arg_3_ in arg[3]],
      {k_arg_4_ : param_t.from_msgpack(v_arg_4_) for k_arg_4_,v_arg_4_ in arg[4].items()},
      [string_rule.from_msgpack(elem_arg_5_) for elem_arg_5_ in arg[5]],
      {k_arg_6_ : param_t.from_msgpack(v_arg_6_) for k_arg_6_,v_arg_6_ in arg[6].items()},
      [num_rule.from_msgpack(elem_arg_7_) for elem_arg_7_ in arg[7]])

class config_data:
  def __init__(self, method, converter):
    self.method = method
    self.converter = converter

  def to_msgpack(self):
    return (
      self.method,
      self.converter,
      )

  @staticmethod
  def from_msgpack(arg):
    return config_data(
      arg[0],
      converter_config.from_msgpack(arg[1]))

class datum:
  def __init__(self, sv, nv):
    self.sv = sv
    self.nv = nv

  def to_msgpack(self):
    return (
      self.sv,
      self.nv,
      )

  @staticmethod
  def from_msgpack(arg):
    return datum(
      [ (elem_arg_0_[0], elem_arg_0_[1], )  for elem_arg_0_ in arg[0]],
      [ (elem_arg_1_[0], elem_arg_1_[1], )  for elem_arg_1_ in arg[1]])






import msgpackrpc
from types import *


class recommender:
  def __init__ (self, host, port):
    address = msgpackrpc.Address(host, port)
    self.client = msgpackrpc.Client(address)

  def set_config (self, name, c):
    retval = self.client.call('set_config', name, c)
    return retval

  def get_config (self, name):
    retval = self.client.call('get_config', name)
    return config_data.from_msgpack(retval)

  def clear_row (self, name, id):
    retval = self.client.call('clear_row', name, id)
    return retval

  def update_row (self, name, id, arg2):
    retval = self.client.call('update_row', name, id, arg2)
    return retval

  def clear (self, name):
    retval = self.client.call('clear', name)
    return retval

  def complete_row_from_id (self, name, id):
    retval = self.client.call('complete_row_from_id', name, id)
    return datum.from_msgpack(retval)

  def complete_row_from_data (self, name, arg1):
    retval = self.client.call('complete_row_from_data', name, arg1)
    return datum.from_msgpack(retval)

  def similar_row_from_id (self, name, id, size):
    retval = self.client.call('similar_row_from_id', name, id, size)
    return similar_result.from_msgpack(retval)

  def similar_row_from_data (self, name, data, size):
    retval = self.client.call('similar_row_from_data', name, data, size)
    return similar_result.from_msgpack(retval)

  def decode_row (self, name, id):
    retval = self.client.call('decode_row', name, id)
    return datum.from_msgpack(retval)

  def get_all_rows (self, name):
    retval = self.client.call('get_all_rows', name)
    return [elem_retval for elem_retval in retval]

  def similarity (self, name, lhs, rhs):
    retval = self.client.call('similarity', name, lhs, rhs)
    return retval

  def l2norm (self, name, arg1):
    retval = self.client.call('l2norm', name, arg1)
    return retval

  def save (self, name, arg1):
    retval = self.client.call('save', name, arg1)
    return retval

  def load (self, name, arg1):
    retval = self.client.call('load', name, arg1)
    return retval

  def get_status (self, name):
    retval = self.client.call('get_status', name)
    return {k_retval : {k_v_retval : v_v_retval for k_v_retval,v_v_retval in v_retval.items()} for k_retval,v_retval in retval.items()}





try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

import os
import sys
import unittest
import os.path
import platform

sys.path.append('jubatus')
sys.path.append('test')

def read(name):
    return open(os.path.join(os.path.dirname(__file__), name)).read()

setup(name='jubatus',
      version="0.2.2",
      description="client for jubatus: highly distributed online machine learning system",
      long_description=read('README.rst'),
      author='PFI & NTT',
      author_email='',
      url='http://jubat.us',
      license='LGPL',
      platforms='Linux',
      packages=['jubatus', 'jubatus/classifier', 'jubatus/recommender', 'jubatus/stat', 'jubatus/regression'],
      install_requires=[
          'msgpack-python>=0.1.9',
      ],

      entry_points="",
      ext_modules=[],
      classifiers=[
          'Development Status :: 2 - Pre-Alpha',
          'Environment :: Other Environment',
          'Intended Audience :: Developers',
          'Intended Audience :: Science/Research',
          'License :: OSI Approved :: GNU Library or Lesser General Public License (LGPL)',
          'Operating System :: POSIX :: Linux',
          'Programming Language :: Python',
          'Topic :: Scientific/Engineering :: Information Analysis'
      ],

      test_suite='it_single_test.suite',
)




# This file is auto-generated from src/server/stat.idl
# *** DO NOT EDIT ***


import sys
import msgpack


class config_data:
  def __init__(self, window_size):
    self.window_size = window_size

  def to_msgpack(self):
    return (
      self.window_size,
      )

  @staticmethod
  def from_msgpack(arg):
    return config_data(
      arg[0])


